SystemOrganization addCategory: #'StyleProfile-Basic-Locator'!
SystemOrganization addCategory: #'StyleProfile-WebApp'!
SystemOrganization addCategory: #'StyleProfile-Tests-WebApp'!
SystemOrganization addCategory: #'StyleProfile-DAO'!
SystemOrganization addCategory: #'StyleProfile-Business-Model'!
SystemOrganization addCategory: #'StyleProfile-Tests-Basic-Locator'!
SystemOrganization addCategory: #'StyleProfile-Tests-DAO'!
SystemOrganization addCategory: #'StyleProfile-Tests-Business-Model'!

TestCase subclass: #AddressTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'StyleProfile-Tests-Business-Model'!

!AddressTest methodsFor: 'as yet unclassified' stamp: 'IgorArouca 4/22/2013 12:19'!
testInstatiation

	| address |

	address :=
		Address
			newStreet:  '906 W Clark Street'
			city: 'Urbana'
			state: State IL
			country: 'US'
			zipcode: '61801'.

	self assert: address street equals: '906 W Clark Street'.
	self assert: address city equals: 'Urbana'.
	self assert: address state equals: State IL.
	self assert: address country equals: 'US'.
	self assert: address zipcode equals: '61801'
! !

TestCase subclass: #CategoryTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'StyleProfile-Tests-Business-Model'!

!CategoryTest methodsFor: 'tests' stamp: 'IgorArouca 3/24/2013 23:10'!
createFloralCategory

	^ Category newName: #floral description: 'This category is about flowers'! !

!CategoryTest methodsFor: 'tests' stamp: 'IgorArouca 3/24/2013 23:10'!
testCreation

	| floral |

	floral := self createFloralCategory.

	self assert: floral name equals: 'floral'.
	self assert: floral description equals: 'This category is about flowers'! !

!CategoryTest methodsFor: 'tests' stamp: 'IgorArouca 3/24/2013 23:49'!
testCreationDuplicateError

	self createFloralCategory.	

	self should: [ Category newName: #floral description: 'This is a duplicate category' ]
		 raise: Error
		 description: 'A category named #floral already exists'
! !

TestCase subclass: #ConnectionServiceLocatorTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'StyleProfile-Tests-Basic-Locator'!

!ConnectionServiceLocatorTest methodsFor: 'as yet unclassified' stamp: 'IgorArouca 3/23/2013 20:36'!
connectionSettings

	| settingsDict settingsStream tempStream |

	settingsDict := Dictionary new
		at: #host put: '127.0.0.1';
		at: #port put: '3306';
		at: #database put: 'information_schema';
		at: #user put: 'root';
		at: #password put: '';
		yourself.

	tempStream := String new writeStream.
	settingsDict storeOn: tempStream.

	^ ReadStream on: tempStream contents
! !

!ConnectionServiceLocatorTest methodsFor: 'tests' stamp: 'IgorArouca 3/23/2013 20:54'!
testConnection

	| strategy connection locator result |

	strategy := DBXManualConnectionStrategy newConnectionSettings: self connectionSettings.

	"Sets the default service to connect to the database above"
	locator := ConnectionServiceLocator instance connectionStrategy: strategy.

	"The returned connection is eady to receive queries to be executed agains the db"
	connection := locator connection.

	"Runs a simple query to test connection"
	result := connection execute: 'select * from engines'.

	self assert: result rows isEmpty equals: false. 

	"Closes the connection to release allocated resources"
	connection close
! !

!ConnectionServiceLocatorTest methodsFor: 'tests' stamp: 'IgorArouca 3/23/2013 21:07'!
testConnectionWithoutStrategy

	| locator |

	locator := ConnectionServiceLocator instance.
	locator connectionStrategy: nil.

	self should: [ locator connection ] raise: Error
! !

TestCase subclass: #DAOFactoryTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'StyleProfile-Tests-DAO'!

!DAOFactoryTest methodsFor: 'as yet unclassified' stamp: 'IgorArouca 4/21/2013 22:49'!
testDAONotFoundError

	self	 should: [ DAOFactory dataAccessObjectFor: Object ]
		 raise: Error
		 withExceptionDo: [ :exception |
			self assert: (exception description = 'Error: There is no ObjectDAO in the system.')
		]
! !

!DAOFactoryTest methodsFor: 'as yet unclassified' stamp: 'IgorArouca 4/21/2013 22:31'!
testDAORetrieval
 
	self assert: (DAOFactory dataAccessObjectFor: User) class equals: UserDAO.
! !

TestCase subclass: #PictureDAOTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'StyleProfile-Tests-DAO'!

!PictureDAOTest methodsFor: 'as yet unclassified' stamp: 'IgorArouca 3/24/2013 12:24'!
testInstatiation

 
! !

TestCase subclass: #StyleTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'StyleProfile-Tests-Business-Model'!

!StyleTest methodsFor: 'as yet unclassified' stamp: 'IgorArouca 3/24/2013 13:00'!
testCreation

	| style |

	style := Style newName: 's' description: '' category: Category new.
	self assert: style name equals: 'd '.
	self assert: style description equals: 's'.! !

!StyleTest methodsFor: 'as yet unclassified' stamp: 'IgorArouca 3/24/2013 12:34'!
testCreationWithoutNameAndDescription

	self should: [ Style new ] raise: Error
! !

TestCase subclass: #UserDAOTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'StyleProfile-Tests-DAO'!

!UserDAOTest methodsFor: 'as yet unclassified' stamp: 'IgorArouca 4/22/2013 00:41'!
testSave

	User new! !

TestCase subclass: #UserTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'StyleProfile-Tests-Business-Model'!

!UserTest methodsFor: 'as yet unclassified' stamp: 'IgorArouca 4/22/2013 00:34'!
sampleAddress

	Address
		newStreet: '906 W Clark St'
		city: 'Urbana'
		state: #IL
		country: 'USA'
		zipcode: '61801'
! !

!UserTest methodsFor: 'as yet unclassified' stamp: 'IgorArouca 4/21/2013 23:10'!
testInstatiation

	User
		newFirstName: 'Igor'
		lastName: 'Arouca'
		gender: #M
		age: 31
		educationLevel: #Master
		email: 'arouca2@illinois.edu'
		password: 'a12345678'
		address: self sampleAddress
! !

WAComponent subclass: #WeddingForm
	instanceVariableNames: 'user location'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'StyleProfile-WebApp'!

!WeddingForm commentStamp: 'HamidJahani 4/6/2013 19:19' prior: 0!
problems:
in save, gender is not informed correctly.
who is owner of weddingdate and weddingbudget in the form?
should this form create a new user?


Instance Variables:
	user	<UserDAO>
	location	<LocationDAO>!

!WeddingForm class methodsFor: 'as yet unclassified' stamp: 'HamidJahani 4/1/2013 01:29'!
initialize
    WAAdmin register: self asApplicationAt: 'wedform'! !

!WeddingForm methodsFor: 'initialization' stamp: 'HamidJahani 4/1/2013 01:30'!
initialize
   super initialize.! !

!WeddingForm methodsFor: 'accessing' stamp: 'HamidJahani 4/6/2013 16:09'!
location
	^ location ifNil: [ location := LocationDAO defaultLocation ]
! !

!WeddingForm methodsFor: 'accessing' stamp: 'HamidJahani 4/6/2013 15:39'!
location: aLocationDAO
	location := aLocationDAO! !

!WeddingForm methodsFor: 'rendering' stamp: 'HamidJahani 4/1/2013 00:49'!
renderButtonsOn: html
	html
		tableData;
		tableData: [ html submitButton on: #save of: self ].! !

!WeddingForm methodsFor: 'rendering' stamp: 'HamidJahani 4/6/2013 18:03'!
renderContentOn: html
	html div
		class: 'generic lightbox';
		with: [ 
					html heading: 'Basic information'.
					html
						form: [ 
							html
								table: [ 
									html
										tableRow: [ self renderUserInputOn: html ];
										tableRow: [ self renderLocationInputOn: html ];
										tableRow: [ self renderButtonsOn: html ] ] ] ]	"

Wedding Date:
Estimated Budget:"! !

!WeddingForm methodsFor: 'rendering' stamp: 'HamidJahani 4/6/2013 16:36'!
renderLocationInputOn: html
	html
		tableRow: [ 
					html
						tableData: [ html text: 'Street Address: ' ];
						tableData: [ html textInput on: #street of: self location ] ];
		tableRow: [ 
					html
						tableData: [ html text: 'City: ' ];
						tableData: [ html textInput on: #city of: self location ] ];
		tableRow: [ 
					html
						tableData: [ html text: 'County: ' ];
						tableData: [ html textInput on: #county of: self location ] ];
		tableRow: [ 
					html
						tableData: [ html text: 'State: ' ];
						tableData: [ html textInput on: #state of: self location ] ];
		tableRow: [ 
					html
						tableData: [ html text: 'Zip Code: ' ];
						tableData: [ html textInput on: #zipcode of: self location ] ];
		tableRow: [ 
					html
						tableData: [ html text: 'Country: ' ];
						tableData: [ 
									html select
										list: ValidCountriesDAO list;
										callback: [ :value | self location country: value ] ] ]! !

!WeddingForm methodsFor: 'rendering' stamp: 'HamidJahani 4/6/2013 18:02'!
renderUserInputOn: html
	| genderGroup |
	genderGroup := html radioGroup.
	html
		tableRow: [ 
					html
						tableData: [ html text: 'First Name: ' ];
						tableData: [ html textInput on: #firstName of: self user ] ];
		tableRow: [ 
					html
						tableData: [ html text: 'Last Name: ' ];
						tableData: [ html textInput on: #lastName of: self user ] ];
		tableRow: [ 
					html
						tableData: [ html text: 'Age: ' ];
						tableData: [ html textInput on: #age of: self user ] ];
		tableRow: [ 
					html
						tableData: [ html text: 'Email: ' ];
						tableData: [ html textInput on: #email of: self user ] ];
		tableRow: [ 
					html
						tableData: [ html text: 'Gender: ' ];
						tableData: [ 
									genderGroup radioButton
										selected: self user isMale;
										callback: [ self user gender: #male ].
									html text: 'Male'.
									genderGroup radioButton
										selected: self user isMale not;
										callback: [ self user gender: #female ].
									html text: 'Female' ] ];
		tableRow: [ 
					html
						tableData: [ html text: 'Education Level: ' ];
						tableData: [ 
									html select
										list: ValidEducationLevelsDAO list;
										callback: [ :value | self user educationLevel: value ] ] ]! !

!WeddingForm methodsFor: 'as yet unclassified' stamp: 'HamidJahani 4/6/2013 17:55'!
save
    "this should change to save the submitted data to database"
    self inform: self user firstName , ', ' , self user lastName , ', ' , self user gender asString , ', ' , self location country! !

!WeddingForm methodsFor: 'accessing' stamp: 'HamidJahani 4/6/2013 16:07'!
user
	^ user ifNil: [ user := UserDAO defaultUser ]
! !

!WeddingForm methodsFor: 'accessing' stamp: 'HamidJahani 4/6/2013 14:54'!
user: aUserDAO
	user := aUserDAO! !

Object subclass: #Address
	instanceVariableNames: 'street city state country zipcode'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'StyleProfile-Business-Model'!

!Address class methodsFor: 'as yet unclassified' stamp: 'IgorArouca 4/21/2013 23:54'!
new

	^ self shouldNotImplement
! !

!Address class methodsFor: 'as yet unclassified' stamp: 'IgorArouca 4/21/2013 23:54'!
newStreet: street city: city state: state country: country zipcode: zipcode

	^ super new street: street city: city state: state country: country zipcode: zipcode
! !

!Address methodsFor: 'as yet unclassified' stamp: 'IgorArouca 4/22/2013 12:20'!
city

	^ city
! !

!Address methodsFor: 'as yet unclassified' stamp: 'IgorArouca 4/22/2013 12:20'!
country

	^ country
! !

!Address methodsFor: 'as yet unclassified' stamp: 'IgorArouca 4/22/2013 00:52'!
printOn: aStream

	aStream
		nextPutAll: street;
		nextPutAll: ', '; 
		nextPutAll: city;
		nextPutAll: ', '; 
		nextPutAll: country;
		nextPutAll: ', '; 
		nextPutAll: zipcode
! !

!Address methodsFor: 'as yet unclassified' stamp: 'IgorArouca 4/22/2013 00:33'!
privateValidadeZipcode: aZipcode

	(aZipcode matchesRegex: '\d\d\d\d\d') ifFalse: [
		self error: 'Invalid zipcode: ', aZipcode
	]! !

!Address methodsFor: 'as yet unclassified' stamp: 'IgorArouca 4/21/2013 23:59'!
privateZipcode: aZipcode

	self privateValidadeZipcode: aZipcode.
	zipcode := aZipcode
! !

!Address methodsFor: 'as yet unclassified' stamp: 'IgorArouca 4/22/2013 12:21'!
state

	^ state
! !

!Address methodsFor: 'as yet unclassified' stamp: 'IgorArouca 4/22/2013 12:20'!
street

	^ street
! !

!Address methodsFor: 'as yet unclassified' stamp: 'IgorArouca 4/21/2013 23:57'!
street: aStreet city: aCity state: aState country: aCountry zipcode: aZipcode

	street := aStreet.
	city := aCity.
	state := aState.
	country := aCountry.
	self privateZipcode: aZipcode
! !

!Address methodsFor: 'as yet unclassified' stamp: 'IgorArouca 4/22/2013 12:21'!
zipcode

	^ zipcode
! !

Object subclass: #BaseDAO
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'StyleProfile-DAO'!

BaseDAO class
	instanceVariableNames: 'uniqueInstance'!

BaseDAO class
	instanceVariableNames: 'uniqueInstance'!

!BaseDAO class methodsFor: 'as yet unclassified' stamp: 'IgorArouca 4/21/2013 22:22'!
instance

	^ uniqueInstance ifNil: [ uniqueInstance := self basicNew initialize ]
! !

!BaseDAO class methodsFor: 'as yet unclassified' stamp: 'IgorArouca 4/21/2013 22:23'!
new

	^ self shouldNotImplement
! !

!BaseDAO methodsFor: 'as yet unclassified' stamp: 'IgorArouca 3/23/2013 21:11'!
connection

	^ ConnectionServiceLocator instance connection
! !

BaseDAO subclass: #LocationDAO
	instanceVariableNames: 'location_id street city county state zipcode country'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'StyleProfile-DAO'!

!LocationDAO commentStamp: 'HamidJahani 4/6/2013 15:03' prior: 0!
I create a data structure to store the location attributes.
"Location(location_id,address1,address2,city,state,country,zip)"

Instance Variables:
	street	<ProtoObject>
	city	<ProtoObject>
	county	<ProtoObject>
	state	<ProtoObject>
	zipcode	<ProtoObject>
	country	<ProtoObject>!

!LocationDAO class methodsFor: 'as yet unclassified' stamp: 'HamidJahani 4/6/2013 16:09'!
defaultLocation
	^ self new
		location_id: '';
		street: '205 N MATHEWS AVE';
		city: 'Urbana';
		county: 'Champaign';
		state: 'IL';
		country: 'USA';
		zipcode: '61801';
		yourself
		
	"Location(location_id,address1,address2,city,state,country,zip)"! !

!LocationDAO methodsFor: 'accessing' stamp: 'HamidJahani 4/6/2013 13:30'!
city
	^ city! !

!LocationDAO methodsFor: 'accessing' stamp: 'HamidJahani 4/6/2013 13:30'!
city: anObject
	city := anObject! !

!LocationDAO methodsFor: 'accessing' stamp: 'HamidJahani 4/6/2013 13:30'!
country
	^ country! !

!LocationDAO methodsFor: 'accessing' stamp: 'HamidJahani 4/6/2013 13:30'!
country: anObject
	country := anObject! !

!LocationDAO methodsFor: 'accessing' stamp: 'HamidJahani 4/6/2013 13:30'!
county
	^ county! !

!LocationDAO methodsFor: 'accessing' stamp: 'HamidJahani 4/6/2013 13:30'!
county: anObject
	county := anObject! !

!LocationDAO methodsFor: 'accessing' stamp: 'HamidJahani 4/6/2013 15:42'!
location_id
	^ location_id! !

!LocationDAO methodsFor: 'accessing' stamp: 'HamidJahani 4/6/2013 15:42'!
location_id: anObject
	location_id := anObject! !

!LocationDAO methodsFor: 'accessing' stamp: 'HamidJahani 4/6/2013 13:30'!
state
	^ state! !

!LocationDAO methodsFor: 'accessing' stamp: 'HamidJahani 4/6/2013 13:30'!
state: anObject
	state := anObject! !

!LocationDAO methodsFor: 'accessing' stamp: 'HamidJahani 4/6/2013 13:30'!
street
	^ street! !

!LocationDAO methodsFor: 'accessing' stamp: 'HamidJahani 4/6/2013 13:30'!
street: anObject
	street := anObject! !

!LocationDAO methodsFor: 'accessing' stamp: 'HamidJahani 4/6/2013 13:30'!
zipcode
	^ zipcode! !

!LocationDAO methodsFor: 'accessing' stamp: 'HamidJahani 4/6/2013 13:30'!
zipcode: anObject
	zipcode := anObject! !

BaseDAO subclass: #PictureDAO
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'StyleProfile-DAO'!

BaseDAO subclass: #UserDAO
	instanceVariableNames: 'firstName lastName email age educationLevel gender'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'StyleProfile-DAO'!

!UserDAO commentStamp: 'HamidJahani 4/6/2013 15:04' prior: 0!
I store the user attributes in my instances.
"User(user_id,first_name,last_name,birthdate,gender,user_location_id,favorite_color_id,phone,email,username,password,password_salt)"

Instance Variables:
	firstName	<ProtoObject>
	lastName	<ProtoObject>
	email	<ProtoObject>
	street	<ProtoObject>
	city	<ProtoObject>
	county	<ProtoObject>
	state	<ProtoObject>
	zipcode	<ProtoObject>
	country	<ProtoObject>!

!UserDAO class methodsFor: 'as yet unclassified' stamp: 'HamidJahani 4/6/2013 16:07'!
defaultUser
	^ self new
		firstName: 'Hamid';
		lastName: 'Jahani';
		email: 'jahanim1@illinois.edu'
		yourself! !

!UserDAO class methodsFor: 'as yet unclassified' stamp: 'HamidJahani 4/6/2013 17:24'!
gender
	^ #(#male #female)! !

!UserDAO methodsFor: 'accessing' stamp: 'HamidJahani 4/6/2013 16:42'!
age
	^ age! !

!UserDAO methodsFor: 'accessing' stamp: 'HamidJahani 4/6/2013 16:42'!
age: anObject
	age := anObject! !

!UserDAO methodsFor: 'accessing' stamp: 'HamidJahani 4/6/2013 16:42'!
educationLevel
	^ educationLevel! !

!UserDAO methodsFor: 'accessing' stamp: 'HamidJahani 4/6/2013 16:42'!
educationLevel: anObject
	educationLevel := anObject! !

!UserDAO methodsFor: 'accessing' stamp: 'HamidJahani 4/1/2013 00:03'!
email
	^ email! !

!UserDAO methodsFor: 'accessing' stamp: 'HamidJahani 4/1/2013 00:03'!
email: anObject
	email := anObject! !

!UserDAO methodsFor: 'accessing' stamp: 'HamidJahani 4/1/2013 00:03'!
firstName
	^ firstName! !

!UserDAO methodsFor: 'accessing' stamp: 'HamidJahani 4/1/2013 00:03'!
firstName: anObject
	firstName := anObject! !

!UserDAO methodsFor: 'accessing' stamp: 'HamidJahani 4/6/2013 17:33'!
gender
	^ gender! !

!UserDAO methodsFor: 'accessing' stamp: 'HamidJahani 4/6/2013 17:41'!
gender: anObject
	gender = anObject! !

!UserDAO methodsFor: 'as yet unclassified' stamp: 'HamidJahani 4/6/2013 18:00'!
isMale
	^ gender == #male! !

!UserDAO methodsFor: 'accessing' stamp: 'HamidJahani 4/1/2013 00:03'!
lastName
	^ lastName! !

!UserDAO methodsFor: 'accessing' stamp: 'HamidJahani 4/1/2013 00:03'!
lastName: anObject
	lastName := anObject! !

BaseDAO subclass: #ValidCountriesDAO
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'StyleProfile-DAO'!

!ValidCountriesDAO commentStamp: 'HamidJahani 4/6/2013 15:02' prior: 0!
I am a singleton class responsible to extract the list of valid countries from the databse and store them as an object in memory.
questions: how to make a singleton class?

Instance Variables:
	countryList	<ProtoObject>!

!ValidCountriesDAO class methodsFor: 'as yet unclassified' stamp: 'HamidJahani 4/6/2013 16:36'!
list
	^ #(#UnitedStates #China #India #France)! !

BaseDAO subclass: #ValidEducationLevelsDAO
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'StyleProfile-DAO'!

!ValidEducationLevelsDAO class methodsFor: 'as yet unclassified' stamp: 'HamidJahani 4/6/2013 16:34'!
list
	^ #(#Graduate #PostGraduate #PhD)! !

Object subclass: #Category
	instanceVariableNames: 'name description'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'StyleProfile-Business-Model'!

!Category class methodsFor: 'as yet unclassified' stamp: 'IgorArouca 3/24/2013 13:20'!
newName: aName description: aDescription

	^ super new privateName: aName description: aDescription
! !

!Category methodsFor: 'as yet unclassified' stamp: 'IgorArouca 3/24/2013 23:50'!
checkIfNameIsUnique: aName

	((self class all collect: [ :category | category name ]) includes: aName) ifTrue: [ ^ self ]

	self error: 'A category named ', aName, ' alredy exists.'
! !

!Category methodsFor: 'accessing' stamp: 'HamidJahani 3/24/2013 14:44'!
description 
	^ description ! !

!Category methodsFor: 'accessing' stamp: 'HamidJahani 3/24/2013 14:44'!
name
	^ name! !

!Category methodsFor: 'private' stamp: 'IgorArouca 3/24/2013 23:39'!
privateName: aName

	aName isEmptyOrNil ifTrue: [ ^ self error: 'A category needs a name' ].

	self checkIfNameIsUnique: aName.

	name := aName asSymbol
! !

!Category methodsFor: 'private' stamp: 'HamidJahani 3/24/2013 14:42'!
privateName: aName description: aDescription

	self privateName: aName.
	description := aDescription
! !

Object subclass: #ConnectionServiceLocator
	instanceVariableNames: 'connectionStrategy'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'StyleProfile-Basic-Locator'!

ConnectionServiceLocator class
	instanceVariableNames: 'uniqueInstance connectionSettings'!

ConnectionServiceLocator class
	instanceVariableNames: 'uniqueInstance connectionSettings'!

!ConnectionServiceLocator class methodsFor: 'instance creation' stamp: 'IgorArouca 3/14/2013 08:58'!
instance

	^ uniqueInstance ifNil: [ uniqueInstance := self basicNew initialize ]
! !

!ConnectionServiceLocator class methodsFor: 'instance creation' stamp: 'IgorArouca 3/14/2013 08:59'!
new

	^ self shouldNotImplement
! !

!ConnectionServiceLocator methodsFor: 'as yet unclassified' stamp: 'IgorArouca 3/23/2013 19:47'!
connection

	connectionStrategy ifNil: [
		^ self error: 'Please use the #connectionStrategy: method to tell me how I should get a connection for you'
	].

	^ connectionStrategy connection
! !

!ConnectionServiceLocator methodsFor: 'as yet unclassified' stamp: 'IgorArouca 3/23/2013 19:16'!
connectionStrategy: aConnectionStrategy

	connectionStrategy := aConnectionStrategy
! !

Object subclass: #ConnectionStrategy
	instanceVariableNames: 'connectionSettings'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'StyleProfile-Basic-Locator'!

!ConnectionStrategy class methodsFor: 'as yet unclassified' stamp: 'IgorArouca 3/23/2013 18:33'!
newConnectionSettings: aStream

	^ super new connectionSettings: (self privateRetrieveConnectionSettingsDictionaryFrom: aStream)
! !

!ConnectionStrategy class methodsFor: 'as yet unclassified' stamp: 'IgorArouca 3/23/2013 20:27'!
privateRetrieveConnectionSettingsDictionaryFrom: aStream
	"This method encapsulates the reading operation from the stream, which should follow the format defined by the input file used to store the connecion settings"
	
	^ Dictionary readFrom: aStream
! !

!ConnectionStrategy methodsFor: 'as yet unclassified' stamp: 'IgorArouca 3/23/2013 16:48'!
connection

	^ self subclassResponsibility
! !

!ConnectionStrategy methodsFor: 'as yet unclassified' stamp: 'IgorArouca 3/23/2013 18:28'!
connectionSettings: aDictionary

	connectionSettings := aDictionary
! !

ConnectionStrategy subclass: #DBXManualConnectionStrategy
	instanceVariableNames: 'service'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'StyleProfile-Basic-Locator'!

!DBXManualConnectionStrategy methodsFor: 'as yet unclassified' stamp: 'IgorArouca 3/23/2013 21:17'!
connection

	| connection |

	connection := DBXConnection platform: DBXMySQLBackend new settings: self connectionSettings.
	connection connect.
	connection reOpen.

	^ connection
! !

!DBXManualConnectionStrategy methodsFor: 'as yet unclassified' stamp: 'IgorArouca 3/23/2013 19:55'!
connectionSettings

	^ DBXConnectionSettings
		host: self host
		port: self port
		database: self database
		userName: self user
		userPassword: self password
! !

!DBXManualConnectionStrategy methodsFor: 'as yet unclassified' stamp: 'IgorArouca 3/23/2013 19:53'!
database

	^ connectionSettings at: #database
! !

!DBXManualConnectionStrategy methodsFor: 'as yet unclassified' stamp: 'IgorArouca 3/23/2013 19:53'!
host

	^ connectionSettings at: #host
! !

!DBXManualConnectionStrategy methodsFor: 'as yet unclassified' stamp: 'IgorArouca 3/23/2013 19:53'!
password

	^ connectionSettings at: #password
! !

!DBXManualConnectionStrategy methodsFor: 'as yet unclassified' stamp: 'IgorArouca 3/23/2013 19:54'!
port

	^ connectionSettings at: #port
! !

!DBXManualConnectionStrategy methodsFor: 'as yet unclassified' stamp: 'IgorArouca 3/23/2013 19:54'!
user

	^ connectionSettings at: #database
! !

Object subclass: #DAOFactory
	instanceVariableNames: 'dataAccessObjects'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'StyleProfile-DAO'!

DAOFactory class
	instanceVariableNames: 'uniqueInstance'!

DAOFactory class
	instanceVariableNames: 'uniqueInstance'!

!DAOFactory class methodsFor: 'as yet unclassified' stamp: 'IgorArouca 4/21/2013 22:25'!
dataAccessObjectFor: aClass

	| associatedDAO |

	associatedDAO := (aClass name , 'DAO') asSymbol.
	^ (Smalltalk
		at: associatedDAO
		ifAbsent: [ self error: 'There is no ', associatedDAO, ' in the system.' ]
	) instance
! !

Object subclass: #State
	instanceVariableNames: 'abbreviation name'
	classVariableNames: 'AK AL AR AZ CA CO CT DE FL GA HI IA ID IL IN KS KY LA MA MD ME MI MN MO MS MT NC ND NE NH NJ NM NV NY OH OK OR PA RI SC SD TN TX UT VA VT WA WI WV WY'
	poolDictionaries: ''
	category: 'StyleProfile-Business-Model'!

!State class methodsFor: 'as yet unclassified' stamp: 'IgorArouca 4/22/2013 12:03'!
abbreviation: aSymbol name: aString

	| state |

	state := super new privateAbbreviation: aSymbol name: aString.

	(self classPool includesKey: aSymbol) ifFalse: [ self addClassVarNamed: aSymbol ].

	^ self classPool at: aSymbol put: state
! !

!State class methodsFor: 'as yet unclassified' stamp: 'IgorArouca 4/22/2013 11:53'!
abbreviations

	^ self classPool keys sort
! !

!State class methodsFor: 'as yet unclassified' stamp: 'IgorArouca 4/22/2013 12:10'!
doesNotUnderstand: aMessage

	^ self classPool at: aMessage selector asUppercase asSymbol
! !

!State class methodsFor: 'as yet unclassified' stamp: 'IgorArouca 4/22/2013 10:59'!
initialize

	super initialize.
	self initializeStates
! !

!State class methodsFor: 'as yet unclassified' stamp: 'IgorArouca 4/22/2013 11:59'!
initializeStates

	self abbreviation: #AL name: 'Alabama'.
	self abbreviation: #AK name: 'Alaska'.
	self abbreviation: #AZ name: 'Arizona'.
	self abbreviation: #AR name: 'Arkansas'.
	self abbreviation: #CA name: 'California'.
	self abbreviation: #CO name: 'Colorado'.
	self abbreviation: #CT name: 'Connecticut'.
	self abbreviation: #DE name: 'Delaware'.
	self abbreviation: #FL name: 'Florida'.
	self abbreviation: #GA name: 'Georgia'.
	self abbreviation: #HI name: 'Hawaii'.
	self abbreviation: #ID name: 'Idaho'.
	self abbreviation: #IL name: 'Illinois'.
	self abbreviation: #IN name: 'Indiana'.
	self abbreviation: #IA name: 'Iowa'.
	self abbreviation: #KS name: 'Kansas'.
	self abbreviation: #KY name: 'Kentucky'.
	self abbreviation: #LA name: 'Louisiana'.
	self abbreviation: #ME name: 'Maine'.
	self abbreviation: #MD name: 'Maryland'.
	self abbreviation: #MA name: 'Massachusetts'.
	self abbreviation: #MI name: 'Michigan'.
	self abbreviation: #MN name: 'Minnesota'.
	self abbreviation: #MS name: 'Mississippi'.
	self abbreviation: #MO name: 'Missouri'.
	self abbreviation: #MT name: 'Montana'.
	self abbreviation: #NE name: 'Nebraska'.
	self abbreviation: #NV name: 'Nevada'.
	self abbreviation: #NH name: 'New Hampshire'.
	self abbreviation: #NJ name: 'New Jersey'.
	self abbreviation: #NM name: 'New Mexico'.
	self abbreviation: #NY name: 'New York'.
	self abbreviation: #NC name: 'North Carolina'.
	self abbreviation: #ND name: 'North Dakota'.
	self abbreviation: #OH name: 'Ohio'.
	self abbreviation: #OK name: 'Oklahoma'.
	self abbreviation: #OR name: 'Oregon'.
	self abbreviation: #PA name: 'Pennsylvania'.
	self abbreviation: #RI name: 'Rhode Island'.
	self abbreviation: #SC name: 'South Carolina'.
	self abbreviation: #SD name: 'South Dakota'.
	self abbreviation: #TN name: 'Tennessee'.
	self abbreviation: #TX name: 'Texas'.
	self abbreviation: #UT name: 'Utah'.
	self abbreviation: #VT name: 'Vermont'.
	self abbreviation: #VA name: 'Virginia'.
	self abbreviation: #WA name: 'Washington'.
	self abbreviation: #WV name: 'West Virginia'.
	self abbreviation: #WI name: 'Wisconsin'.
	self abbreviation: #WY name: 'Wyoming'
! !

!State class methodsFor: 'as yet unclassified' stamp: 'IgorArouca 4/22/2013 11:58'!
names

	^ (self classPool values collect: [ :state | state name ]) sort
! !

!State class methodsFor: 'as yet unclassified' stamp: 'IgorArouca 4/22/2013 11:02'!
new

	^ self shouldNotImplement
! !

!State methodsFor: 'as yet unclassified' stamp: 'IgorArouca 4/22/2013 11:57'!
abbreviation

	^ abbreviation
! !

!State methodsFor: 'as yet unclassified' stamp: 'IgorArouca 4/22/2013 11:57'!
name

	^ name
! !

!State methodsFor: 'as yet unclassified' stamp: 'IgorArouca 4/22/2013 12:15'!
printOn: aStream

	aStream nextPutAll: self name; nextPutAll: ' ('; nextPutAll: self abbreviation; nextPutAll: ')'
! !

!State methodsFor: 'as yet unclassified' stamp: 'IgorArouca 4/22/2013 11:03'!
privateAbbreviation: aSymbol name: aString

	abbreviation := aSymbol.
	name := aString
! !

Object subclass: #Style
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'StyleProfile-Business-Model'!

!Style class methodsFor: 'as yet unclassified' stamp: 'IgorArouca 3/24/2013 12:33'!
new

	^ self error: 'I need a name and description. Please use method #newName:descroption: instead.'
! !

!Style class methodsFor: 'as yet unclassified' stamp: 'IgorArouca 3/24/2013 13:01'!
newName: aName description: aDescription category: aCategory

! !

Object subclass: #User
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'StyleProfile-Business-Model'!

Object subclass: #WeddingFormTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'StyleProfile-Tests-WebApp'!
State initialize!
WeddingForm initialize!
